from . import __version__

import click
import requests

from cat_fact.client import CatClient

cat_client = CatClient(requests.Session(), "http://cat-fact.herokuapp.com")



@click.command()
@click.option("--animal", default="cat")
@click.version_option(version=__version__)
def cli(animal, verbose=False):
    random_fact = cat_client.get_random_fact(animal)
    if not random_fact:
        click.echo("Unable to get facts at the moment :'(")
    else:
        click.echo(random_fact["text"])





import posixpath


class CatClient(object):

    def __init__(self, session, host_url):
        self._session = session
        self._host_url = host_url
        self.animals = ["cat", "horse", "dog"]

    def animal_exists(self, animal):
        return animal in self.animals

    def rooted_uri(self, *args):
        return posixpath.join(self._host_url, *args)

    def get_random_fact(self, animal):
        if not self.animal_exists(animal):
            return None
        api_end_point = self.rooted_uri(
            "facts/random",
            "?animal_type={}".format(animal)
        )
        response = self._session.get(api_end_point)
        if response.ok:
            return response.json()
        return []




import sys
import re
import os.path

from setuptools import setup, find_packages


with open("README.md") as f:
    long_description = f.read()


def get_version():
    """Returns the package version taken from version.py
    """
    root = os.path.dirname(__file__)
    version_path = os.path.join(root, "cat_fact/__init__.py")
    text = open(version_path).read()
    rx = re.compile("^__version__ = '(.*)'", re.M)
    m = rx.search(text)
    version = m.group(1)
    return version


install_requires = [
    "click>=6.7",
    "requests>=2.21"
]


setup(
    name="cat_fact",
    version=get_version(),
    author="Shaik Sohail Yunus",
    author_email="sohail.yunusha1@gmail.com",
    maintainer="Shaik Sohail Yunus",
    maintainer_email="sohail.yunusha1@gmail.com",
    description="Get random cat facts fromt the internet " + u"\U0001F638",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=install_requires,
    packages=find_packages(),
    url="https://github.com/sohail535/cat_fact",
    entry_points="""
        [console_scripts]
        catFact = cat_fact.cli:cli
    """
)

